if select(4, GetBuildInfo()) >= 50000 then
	return
end

local libName, lib = ...
local s = SpellFlashAddon
local c = BittensSpellFlashLibrary

local math = math
local pairs = pairs
local select = select

c.SLOW_MELEE_DEBUFFS = {
    68055, -- Judgements of the Just 
    58180, -- Infected Wounds 
    59921, -- Frost Fever 
    6343, -- Thunder Clap 
    8042, -- Earth Shock 
    50285, -- Dust Cloud 
    16914, -- Hurricane 
    90314, --Tailspin
}

c.ARMOR_DEBUFFS = {
    7386, -- Sunder Armor
    8647, -- Expose Armor
    91565, -- Faerie Fire
    35387, -- Corrosive Spit
    50498, -- Tear Armor
}

c.PHYSICAL_DAMAGE_DEBUFFS = {
    702, -- Curse of Weakness
    99, -- Demoralizing Roar
    1160, -- Demoralizing Shout 
    81130, -- Scarlet Fever 
    26017, -- Vindication
}

c.BLEED_DEBUFFS = {
    33876, -- Mangle
    46857, -- Trauma
    16511, -- Hemorrhage
    50271, -- Tendon Rip
    35290, -- Gore
    57386, -- Stampede
}

c.FIVE_PERCENT_BUFFS = {
    1126, -- Mark of the Wild
    20217, -- Blessing of Kings
    90363, -- Embrace of the Shale Spider
--    117666, -- Legacy of the Emperor
}

c.STAMINA_BUFFS = {
    79105, -- Power Word: Fortitude
    90364, -- Qiraji Fortitude
    6307, -- Blood Pact
    469, -- Commanding Shout
}

c.SHADOW_RESISTANCE_BUFFS = {
    19891, -- Resistance Aura
    79107, -- Shadow Protection
}

c.INTELLECT_BUFFS = {
    1459, -- Arcane Brilliance
    61316, -- Dalaran Brilliance
    52109, -- Flametongue Totem
    54424, -- Fel Intelligence
}

c.MANA_BUFFS = {
    1459, -- Arcane Brilliance
    61316, -- Dalaran Brilliance
    54424, -- Fel Intelligence
}

c.ATTACK_POWER_BUFFS = {
    79102, -- Blessing of Might
    53138, -- Abomination's Might
    19506, -- Trueshot Aura
    30808, -- Unleashed Rage
}

c.MP5_BUFFS = {
    19740, -- Blessing of Might
    5675, -- Mana Spring Totem
    54424, -- Fel Intelligence
}

c.CRIT_DEBUFFS = {
    22959, -- Critical Mass
    17800, -- Shadow and Flame
}

c.BLOODLUST_BUFFS = {
    90355, -- Ancient Hysteria
    80353, -- Time Warp
    2825, -- Bloodlust
    32182, -- Heroism
}

c.STR_AGI_BUFFS = {
    57330, -- Horn of Winter
    93435, -- Roar of Courage
    8075, -- Strength of Earth Totem
    6673, -- Battle Shout
}

c.SPELL_DAMAGE_DEBUFFS = {
    1490, -- Curse of the Elements
    86105, -- Jinx: Curse of the Elements
    58410, -- Master Poisoner
    51160, -- Ebon Plaguebringer
    48506, -- Earth and Moon
    34889, -- Fire Breath
    24844, -- Lightning Breath
}

-- This function is going away.  Use c.KeepBuffsUp instead (found in Buffs.lua).
function c.RotateCooldowns(uncontrolledBuffs, ...)
	for _, buff in pairs(uncontrolledBuffs) do
		if c.HasBuff(buff) then
			return
		end
	end
	for i = 1, select("#", ...) do
		buff = select(i, ...)
		local spell
		if lib.A.SpellIDs then
			spell = c.GetSpell(buff)
		else
			spell = lib.A.spells[buff]
		end
		buff = spell.Buff or buff
		if s.Buff(
			buff, 
			"player", 
			c.GetBusyTime(spell.NoGCD), 
			nil, 
			nil, 
			spell.UseBuffID) then
			
			return
		end
	end
	if lib.A.SpellIDs then
		for i = 1, select("#", ...) do
			buff = select(i, ...)
			if s.CheckThenFlash(c.GetSpell(buff)) then
				return true
			end
		end
	else
		return lib.A.Flash(...)
	end
end

function c.HasBuff(name, noGCD)
	local duration = s.BuffDuration(c.GetID(name), "player")
	if duration == 0 then
		-- duration == 0 for permanent buffs
		return s.Buff(c.GetID(name), "player")
	else
		return duration > c.GetBusyTime(noGCD)
	end
end

function c.GetBuffDuration(name, noGCD)
	return math.max(
		s.BuffDuration(c.GetID(name), "player") - c.GetBusyTime(noGCD), 0)
end

function c.GetBuffStack(name)
	if c.HasBuff(name) then -- ensure it's not going to expire
		return s.BuffStack(c.GetID(name), "player")
	else
		return 0
	end
end

function c.HasMyDebuff(name, noGCD)
	return c.GetMyDebuffDuration(name, noGCD) > 0
end

function c.GetMyDebuffStack(name)
	if c.HasMyDebuff(name) then -- ensure it's not going to expire
		return s.MyDebuffStack(c.GetID(name))
	else
		return 0
	end
end

function c.GetMyDebuffDuration(name, noGCD)
	return math.max(s.MyDebuffDuration(c.GetID(name)) - c.GetBusyTime(noGCD), 0)
end

function c.GetDebuffDuration(name, noGCD)
	return math.max(0, s.DebuffDuration(c.GetID(name)) - c.GetBusyTime(noGCD))
end

function c.SelfBuffNeeded(name)
	if s.InCombat() then
		return not c.HasBuff(name)
	else
		return c.GetBuffDuration(name) < 5 * 60
	end
end

function c.RaidBuffNeeded(idTable)
	local duration = 0
	if not s.InCombat() then
		duration = 5 * 60
	end
	local flags = "raid|all|range"
	if idTable == c.INTELLECT_BUFFS then
		flags = flags .. "|mana"
	end
	return not s.Buff(idTable, flags, duration)
end
